/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the examples of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:BSD$
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QtGui>

#include "draglabel.h"

//! [0]
DragLabel::DragLabel(bool full_pile, QWidget *parent)
    : QLabel(parent)
{
    /* Här kan man skapa en ny kortpacke och generera dess bild (renderCard() funktionen). */
}

DragLabel::~DragLabel()
{
    delete card_pile;
}

QString DragLabel::labelText() const
{
    return m_labelText;
}

Pile *DragLabel::getPile()
{
    return card_pile;
}

void DragLabel::renderCard()
{
    QString text = "Empty";
    if (card_pile->peekCard() != NULL) //Pile nonempty
    {
        switch(card_pile->peekCard()->getValue()) {
        case 1: text = "A"; break;
        case 11: text = "J"; break;
        case 12: text = "Q"; break;
        case 13: text = "K"; break;
        default: text.setNum(card_pile->peekCard()->getValue());
        }
    }


    QSize size;
    size.setHeight(100); size.setWidth(70);
    QImage image(size.width(), size.height(),
                 QImage::Format_ARGB32_Premultiplied);
    image.fill(qRgba(0, 0, 0, 0));

    QFont font;
    font.setStyleStrategy(QFont::ForceOutline);

    QPainter painter;
    painter.begin(&image);
    painter.setRenderHint(QPainter::Antialiasing);

    painter.setBrush(Qt::white);
    painter.drawRoundedRect(QRectF(0.5, 0.5, image.width()-1, image.height()-1),
                            25, 25, Qt::RelativeSize);

    int textOffset = 6;
    painter.setFont(font);
    painter.setBrush(Qt::black);
    painter.save();

    //Roterar kortet för att skriva värdet upp och ner
    painter.translate(size.width()-textOffset, size.height()-textOffset);
    painter.rotate(180);
    painter.drawText(QRect(QPoint(0, 0), QSize(30, 30)), Qt::AlignTop, text);
    painter.restore(); //Upphäver alla rotationer

    painter.drawText(QRect(QPoint(textOffset, textOffset), QSize(30, 30)), Qt::AlignTop, text);

    if (card_pile->peekCard() != NULL) //Pile nonempty
    {
        QImage image;
        switch(card_pile->peekCard()->getSuit()) {
        case HEARTS: image = QImage(":images/hearts.png"); break;
        case DIAMONDS: image = QImage(":images/diamonds.png"); break;
        case CLUBS: image = QImage(":images/clubs.png"); break;
        default: image = QImage(":images/spades.png");
        }
        QRectF target(20, 30, size.width()-40, size.height()-60);
        painter.drawImage(target, image);
    }
    painter.end();

    setPixmap(QPixmap::fromImage(image));
    m_labelText = text;
}
